==> docusign-esign-java-4.6.0-sources.jar: com/docusign/esign/model/IdEvidenceViewLink.java <==
package com.docusign.esign.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import java.util.Objects;

/** IdEvidenceViewLink. */
public class IdEvidenceViewLink {
  @JsonProperty("viewLink")
  private String viewLink = null;

  /**
   * viewLink.
   *
   * @return IdEvidenceViewLink
   */
  public IdEvidenceViewLink viewLink(String viewLink) {
    this.viewLink = viewLink;
    return this;
  }

  /**
   * .
   *
   * @return viewLink
   */
  @Schema(description = "")
  public String getViewLink() {
    return viewLink;
  }

  /** setViewLink. */
  public void setViewLink(String viewLink) {
    this.viewLink = viewLink;
  }

  /**
   * Compares objects.
   *
   * @return true or false depending on comparison result.
   */
  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    IdEvidenceViewLink idEvidenceViewLink = (IdEvidenceViewLink) o;
    return Objects.equals(this.viewLink, idEvidenceViewLink.viewLink);
  }

  /** Returns the HashCode. */
  @Override
  public int hashCode() {
    return Objects.hash(viewLink);
  }

  /** Converts the given object to string. */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class IdEvidenceViewLink {\n");

    sb.append("    viewLink: ").append(toIndentedString(viewLink)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> docusign-esign-java-6.4.0-sources.jar: com/docusign/esign/model/IdEvidenceViewLink.java <==
package com.docusign.esign.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serializable;
import java.util.Objects;

/** IdEvidenceViewLink. */
public class IdEvidenceViewLink implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("viewLink")
  private String viewLink = null;

  /**
   * viewLink.
   *
   * @return IdEvidenceViewLink
   */
  public IdEvidenceViewLink viewLink(String viewLink) {
    this.viewLink = viewLink;
    return this;
  }

  /**
   * .
   *
   * @return viewLink
   */
  @Schema(description = "")
  public String getViewLink() {
    return viewLink;
  }

  /** setViewLink. */
  public void setViewLink(String viewLink) {
    this.viewLink = viewLink;
  }

  /**
   * Compares objects.
   *
   * @return true or false depending on comparison result.
   */
  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    IdEvidenceViewLink idEvidenceViewLink = (IdEvidenceViewLink) o;
    return Objects.equals(this.viewLink, idEvidenceViewLink.viewLink);
  }

  /** Returns the HashCode. */
  @Override
  public int hashCode() {
    return Objects.hash(viewLink);
  }

  /** Converts the given object to string. */
  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class IdEvidenceViewLink {\n");

    sb.append("    viewLink: ").append(toIndentedString(viewLink)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
